==> qore-0.8.11.tar.bz2: qore-0.8.11/docs/modules/TelnetClient/html/group__sql__cops.js <==
var group__sql__cops =
[
    [ "COP_APPEND", "../../SqlUtil/html/group__sql__cops.html#ga8e4c9ab6d5ccd9ee6ec73c81620a9f16", null ],
    [ "COP_AS", "../../SqlUtil/html/group__sql__cops.html#gac19d79651b31032968649f644ec2d3da", null ],
    [ "COP_AVG", "../../SqlUtil/html/group__sql__cops.html#ga76347b9d5c1da37258c0f11c539c4e8b", null ],
    [ "COP_COUNT", "../../SqlUtil/html/group__sql__cops.html#ga5de78eaf0c2f9fea151ffad0ed6d80e9", null ],
    [ "COP_DISTINCT", "../../SqlUtil/html/group__sql__cops.html#gae9c9491c6792fbb67aa998911c66792d", null ],
    [ "COP_DIVIDE", "../../SqlUtil/html/group__sql__cops.html#ga2540867988567969c10c289ee1ba1d8a", null ],
    [ "COP_LOWER", "../../SqlUtil/html/group__sql__cops.html#gab78b29922b77d26bfbe1eaab6bf9af42", null ],
    [ "COP_MAX", "../../SqlUtil/html/group__sql__cops.html#ga045c1e1c6df03ff933c5e6c668d8d517", null ],
    [ "COP_MIN", "../../SqlUtil/html/group__sql__cops.html#ga19ebc657a6a4311844a50763a93ce138", null ],
    [ "COP_MINUS", "../../SqlUtil/html/group__sql__cops.html#gadce1c9a9f25e6534ba60944d9c2485ac", null ],
    [ "COP_MULTIPLY", "../../SqlUtil/html/group__sql__cops.html#ga681d65ea16c65717eca1df77a4b59a4d", null ],
    [ "COP_OVER", "../../SqlUtil/html/group__sql__cops.html#ga050e638c47cb995b048f2afff0126f5d", null ],
    [ "COP_PLUS", "../../SqlUtil/html/group__sql__cops.html#ga7d249ab65b0c3af7039ca2c70993a86a", null ],
    [ "COP_PREPEND", "../../SqlUtil/html/group__sql__cops.html#gab295bb9dc1ae58edc09037d74507e000", null ],
    [ "COP_SEQ", "../../SqlUtil/html/group__sql__cops.html#ga89274586533cd4f4121d6d23f10606b9", null ],
    [ "COP_UPPER", "../../SqlUtil/html/group__sql__cops.html#gad732f7795128548587d13d42667781d5", null ],
    [ "COP_VALUE", "../../SqlUtil/html/group__sql__cops.html#ga0bbff735e271b62495539bbc466e7145", null ],
    [ "COP_YEAR", "../../SqlUtil/html/group__sql__cops.html#ga43d8ff458a4db58b45c79851d7b902bf", null ],
    [ "COP_YEAR_DAY", "../../SqlUtil/html/group__sql__cops.html#gacebe3b0582761292a36b07787c6dbd5b", null ],
    [ "COP_YEAR_HOUR", "../../SqlUtil/html/group__sql__cops.html#ga1faef2c3f9981ac91d94065484bfd2f7", null ],
    [ "COP_YEAR_MONTH", "../../SqlUtil/html/group__sql__cops.html#gaa4f20d410a2e77e8051051b8e6eebc0c", null ],
    [ "DefaultCopMap", "../../SqlUtil/html/group__sql__cops.html#gae497d7c4b1316f78ea93522f8b7cd554", null ]
];

==> qore-0.8.12.2.tar.bz2: qore-0.8.12.2/docs/modules/TelnetClient/html/group__sql__cops.js <==
var group__sql__cops =
[
    [ "COP_APPEND", "../../SqlUtil/html/group__sql__cops.html#ga8e4c9ab6d5ccd9ee6ec73c81620a9f16", null ],
    [ "COP_AS", "../../SqlUtil/html/group__sql__cops.html#gac19d79651b31032968649f644ec2d3da", null ],
    [ "COP_AVG", "../../SqlUtil/html/group__sql__cops.html#ga76347b9d5c1da37258c0f11c539c4e8b", null ],
    [ "COP_CAST", "../../SqlUtil/html/group__sql__cops.html#gac46a6a06a7a10ec548593d456b33d724", null ],
    [ "COP_COALESCE", "../../SqlUtil/html/group__sql__cops.html#ga0eeab3270467052722d9246f6b53728b", null ],
    [ "COP_COUNT", "../../SqlUtil/html/group__sql__cops.html#ga5de78eaf0c2f9fea151ffad0ed6d80e9", null ],
    [ "COP_DISTINCT", "../../SqlUtil/html/group__sql__cops.html#gae9c9491c6792fbb67aa998911c66792d", null ],
    [ "COP_DIVIDE", "../../SqlUtil/html/group__sql__cops.html#ga2540867988567969c10c289ee1ba1d8a", null ],
    [ "COP_LOWER", "../../SqlUtil/html/group__sql__cops.html#gab78b29922b77d26bfbe1eaab6bf9af42", null ],
    [ "COP_MAX", "../../SqlUtil/html/group__sql__cops.html#ga045c1e1c6df03ff933c5e6c668d8d517", null ],
    [ "COP_MIN", "../../SqlUtil/html/group__sql__cops.html#ga19ebc657a6a4311844a50763a93ce138", null ],
    [ "COP_MINUS", "../../SqlUtil/html/group__sql__cops.html#gadce1c9a9f25e6534ba60944d9c2485ac", null ],
    [ "COP_MULTIPLY", "../../SqlUtil/html/group__sql__cops.html#ga681d65ea16c65717eca1df77a4b59a4d", null ],
    [ "COP_OVER", "../../SqlUtil/html/group__sql__cops.html#ga050e638c47cb995b048f2afff0126f5d", null ],
    [ "COP_PLUS", "../../SqlUtil/html/group__sql__cops.html#ga7d249ab65b0c3af7039ca2c70993a86a", null ],
    [ "COP_PREPEND", "../../SqlUtil/html/group__sql__cops.html#gab295bb9dc1ae58edc09037d74507e000", null ],
    [ "COP_SEQ", "../../SqlUtil/html/group__sql__cops.html#ga89274586533cd4f4121d6d23f10606b9", null ],
    [ "COP_SEQ_CURRVAL", "../../SqlUtil/html/group__sql__cops.html#ga054b41324be2d26f3d8c18af7a909c88", null ],
    [ "COP_SUBSTR", "../../SqlUtil/html/group__sql__cops.html#ga86a7c99f89ffbb05bf46137c089066d9", null ],
    [ "COP_SUM", "../../SqlUtil/html/group__sql__cops.html#gaf9002f8655aaa571632cda1901d80340", null ],
    [ "COP_UPPER", "../../SqlUtil/html/group__sql__cops.html#gad732f7795128548587d13d42667781d5", null ],
    [ "COP_VALUE", "../../SqlUtil/html/group__sql__cops.html#ga0bbff735e271b62495539bbc466e7145", null ],
    [ "COP_YEAR", "../../SqlUtil/html/group__sql__cops.html#ga43d8ff458a4db58b45c79851d7b902bf", null ],
    [ "COP_YEAR_DAY", "../../SqlUtil/html/group__sql__cops.html#gacebe3b0582761292a36b07787c6dbd5b", null ],
    [ "COP_YEAR_HOUR", "../../SqlUtil/html/group__sql__cops.html#ga1faef2c3f9981ac91d94065484bfd2f7", null ],
    [ "COP_YEAR_MONTH", "../../SqlUtil/html/group__sql__cops.html#gaa4f20d410a2e77e8051051b8e6eebc0c", null ],
    [ "DefaultCopMap", "../../SqlUtil/html/group__sql__cops.html#gae497d7c4b1316f78ea93522f8b7cd554", null ]
];
